@@ -41,7 +41,10 @@ class Codeblock(pytest.Item):
         super().__init__(name, parent=parent)
         self.obj = obj
 
+    # TODO for python 3.7+, stdout=subprocess.PIPE can be replaced by
+    #      capture_output=True
     def runtest(self):
+        output = None
         if self.obj.syntax == "python":
             if self.obj.expect_exception:
                 with pytest.raises(Exception):
@@ -58,34 +61,36 @@ class Codeblock(pytest.Item):
                             + "```\n\n"
                             + f"{e}"
                         )
-
                 output = s.getvalue()
-                if self.obj.expected_output is not None:
-                    if self.obj.expected_output != output:
-                        raise RuntimeError(
-                            f"{self.name}, line {self.obj.lineno}:\n```\n"
-                            + f"Expected output\n```\n{self.obj.expected_output}```\n"
-                            + f"but got\n```\n{output}```"
-                        )
         else:
             assert self.obj.syntax in ["sh", "bash"]
+            executable = {
+                "sh": None,
+                "bash": "/bin/bash",
+                "zsh": "/bin/zsh",
+            }[self.obj.syntax]
             if self.obj.expect_exception:
                 with pytest.raises(Exception):
-                    subprocess.run(self.obj.code, shell=True, check=True)
+                    subprocess.run(
+                        self.obj.code, shell=True, check=True, executable=executable
+                    )
             else:
-                # TODO for python 3.7+, stdout=subprocess.PIPE can be replaced by
-                #      capture_output=True
                 ret = subprocess.run(
-                    self.obj.code, shell=True, check=True, stdout=subprocess.PIPE
+                    self.obj.code,
+                    shell=True,
+                    check=True,
+                    stdout=subprocess.PIPE,
+                    executable=executable,
                 )
                 output = ret.stdout.decode()
-                if self.obj.expected_output is not None:
-                    if self.obj.expected_output != output:
-                        raise RuntimeError(
-                            f"{self.name}, line {self.obj.lineno}:\n```\n"
-                            + f"Expected output\n```\n{self.obj.expected_output}```\n"
-                            + f"but got\n```\n{output}```"
-                        )
+
+        if output is not None and self.obj.expected_output is not None:
+            if self.obj.expected_output != output:
+                raise RuntimeError(
+                    f"{self.name}, line {self.obj.lineno}:\n```\n"
+                    + f"Expected output\n```\n{self.obj.expected_output}```\n"
+                    + f"but got\n```\n{output}```"
+                )
 
     def repr_failure(self, excinfo):
         """Called when self.runtest() raises an exception."""
